@@ -250,6 +250,37 @@ double car_turn_simulation(double turning_time, double car_speed)
     return v;
 }
 
+int find_landing_plane(Vector car_location, Vector car_velocity, double gravity)
+{
+    Vector l = car_location;
+    Vector v = car_velocity;
+    Vector V_simulation_dt = double_to_vector(simulation_dt);
+    double g = gravity;
+
+    if (fabs(l.y) >= 5120)
+        return 5;
+
+    while (1)
+    {
+        if (magnitude(v) < 2300)
+            v.z = v.z + gravity * simulation_dt;
+        l = add(l, multiply(v, V_simulation_dt));
+
+        if (l.x >= 4080)
+            return 0;
+        if (l.x <= -4080)
+            return 1;
+        if (l.y >= 5110)
+            return 2;
+        if (l.y <= -5110)
+            return 3;
+        if (l.z >= 2030)
+            return 4;
+        if (l.z <= 20)
+            return 5;
+    }
+};
+
 struct jump_viable_dat
 {
     _Bool forward;
@@ -260,7 +291,8 @@ struct jump_viable_dat jump_is_viable(double T, double boost_accel, double dista
 {
     struct jump_viable_dat r;
 
-    if (multiply(direction, double_to_vector(distance)).z > 300) {
+    if (multiply(direction, double_to_vector(distance)).z > 300)
+    {
         r.forward = r.backward = 0;
         return r;
     }
@@ -472,7 +504,7 @@ struct aerial_shot aerial_is_viable(double time_remaining, double hitbox_height,
 
         if (enough_speed && enough_boost && enough_time)
             r.found = 1;
-            r.fast = 0;
+        r.fast = 0;
     }
 
     return r;
@@ -701,6 +733,20 @@ static PyObject *method_aerial_shot_is_viable(PyObject *self, PyObject *args)
     return (shot_viable.found) ? Py_True : Py_False;
 }
 
+static PyObject *method_find_landing_plane(PyObject *self, PyObject *args)
+{
+    // int find_landing_plane(Vector car_location, Vector car_velocity, double gravity)
+    Vector car_location, car_velocity;
+    double gravity;
+
+    if (!PyArg_ParseTuple(args, "(ddd)(ddd)d", &car_location.x, &car_location.y, &car_location.z, &car_velocity.x, &car_velocity.y, &car_velocity.z, &gravity))
+        return NULL;
+
+    int landing_plane = find_landing_plane(car_location, car_velocity, gravity);
+
+    return Py_BuildValue("i", landing_plane);
+}
+
 static PyMethodDef methods[] = {
     {"parse_slice_for_jump_shot_with_target", method_parse_slice_for_jump_shot_with_target, METH_VARARGS, "Parse slice for a jump shot with a target"},
     {"parse_slice_for_jump_shot", method_parse_slice_for_jump_shot, METH_VARARGS, "Parse slice for a jump shot"},
@@ -711,6 +757,7 @@ static PyMethodDef methods[] = {
     {"parse_slice_for_aerial_shot_with_target", method_parse_slice_for_aerial_shot_with_target, METH_VARARGS, "Parse slice for an aerial shot with a target"},
     {"parse_slice_for_aerial_shot", method_parse_slice_for_aerial_shot, METH_VARARGS, "Parse slice for an aerial shot"},
     {"aerial_shot_is_viable", method_aerial_shot_is_viable, METH_VARARGS, "Check if an aerial is viable"},
+    {"find_landing_plane", method_find_landing_plane, METH_VARARGS, "Find the plane (side wall, back wall, ceiling, or floor) that the car will collid with first"},
     {NULL, NULL, 0, NULL}};
 
 static struct PyModuleDef module = {
